@@ -1,14 +1,19 @@
 # -*- coding:utf-8 -*-
 from abc import abstractmethod
 from pathlib import Path
-from typing import Union
+from typing import Union, Tuple, Any
+
+from openpyxl import load_workbook, Workbook
+from openpyxl.cell import Cell
+from openpyxl.utils import column_index_from_string
+from openpyxl.utils.cell import coordinate_from_string
 
 
 class BaseRecorder(object):
     """记录器的父类"""
-    SUPPORTS = ()
+    SUPPORTS = ('xlsx', 'csv')
 
-    def __init__(self, path: Union[str, Path], cache_size: int = 50) -> None:
+    def __init__(self, path: Union[str, Path], cache_size: int = None) -> None:
         """初始化                                  \n
         :param path: 保存的文件路径
         :param cache_size: 每接收多少条记录写入文件
@@ -18,7 +23,7 @@ class BaseRecorder(object):
         self._after = []
         self._type = None
         self.path = path
-        self.cache_size = cache_size
+        self.cache_size = cache_size if cache_size is not None else 1000
         self.encoding: str = 'utf-8'
         self.delimiter: str = ','  # csv文件分隔符
         self.quote_char: str = '"'  # csv文件引用符
@@ -100,7 +105,7 @@ class BaseRecorder(object):
         elif isinstance(before, tuple):
             self._before = list(before)
         else:
-            self._before = [str(before)]
+            self._before = [before]
 
     def set_after(self, after: Union[list, tuple, str, dict]) -> None:
         """设置在数据后面补充的列                                \n
@@ -116,7 +121,7 @@ class BaseRecorder(object):
         elif isinstance(after, tuple):
             self._after = list(after)
         else:
-            self._before = [str(after)]
+            self._after = [after]
 
     def clear(self) -> None:
         """清空缓存中的数据"""
@@ -139,13 +144,26 @@ class BaseRecorder(object):
             except Exception as e:
                 if self._data:
                     print(f'\n{self._data}\n\n注意！！以上数据未保存')
-                    break
-
                 if 'Python is likely shutting down' not in str(e):
                     raise
+                break
 
         self._data = []
 
+    def set_head(self, head: Union[list, tuple]) -> None:
+        """设置表头。只有 csv 和 xlsx 格式支持设置表头       \n
+        :param head: 表头，列表或元组
+        :return: None
+        """
+        if self.type == 'xlsx':
+            _set_xlsx_head(self.path, head)
+
+        elif self.type == 'csv':
+            _set_csv_head(self.path, head, self.encoding, self.delimiter, self.quote_char)
+
+        else:
+            raise TypeError('只能对xlsx和csv文件设置表头。')
+
     @abstractmethod
     def add_data(self, data):
         pass
@@ -157,11 +175,13 @@ class BaseRecorder(object):
 
 def _data_to_list(data: Union[list, tuple, dict],
                   before: Union[list, dict, None] = None,
-                  after: Union[list, dict, None] = None) -> list:
-    """将传入的数据转换为列表形式          \n
+                  after: Union[list, dict, None] = None,
+                  process_content: bool = False) -> list:
+    """将传入的数据转换为列表形式                                  \n
     :param data: 要处理的数据
     :param before: 数据前的列
     :param after: 数据后的列
+    :param process_content: 是否执行process_content处理数据
     :return: 转变成列表方式的数据
     """
     return_list = []
@@ -184,20 +204,24 @@ def _data_to_list(data: Union[list, tuple, dict],
         else:
             return_list.extend([str(i)])
 
+    if process_content:
+        return_list = [i.value if isinstance(i, Cell) else i for i in return_list]
     return return_list
 
 
 def _data_to_list_or_dict(data: Union[list, tuple, dict],
                           before: Union[list, tuple, dict, None] = None,
-                          after: Union[list, tuple, dict, None] = None) -> Union[list, dict]:
+                          after: Union[list, tuple, dict, None] = None,
+                          process_content: bool = False) -> Union[list, dict]:
     """将传入的数据转换为列表或字典形式，用于记录到txt或json          \n
     :param data: 要处理的数据
     :param before: 数据前的列
     :param after: 数据后的列
+    :param process_content: 是否执行process_content处理数据
     :return: 转变成列表或字典形式的数据
     """
     if isinstance(data, (list, tuple)):
-        return _data_to_list(data, before, after)
+        return _data_to_list(data, before, after, process_content)
 
     elif isinstance(data, dict):
         if isinstance(before, dict):
@@ -207,3 +231,90 @@ def _data_to_list_or_dict(data: Union[list, tuple, dict],
             data = {**data, **after}
 
         return data
+
+
+def _set_csv_head(file_path: str,
+                  head: Union[list, tuple],
+                  encoding: str = 'utf-8',
+                  delimiter: str = ',',
+                  quotechar: str = '"') -> None:
+    """设置csv文件的表头              \n
+    :param file_path: 文件路径
+    :param head: 表头列表或元组
+    :param encoding: 编码
+    :param delimiter: 分隔符
+    :param quotechar: 引用符
+    :return: None
+    """
+    from csv import writer
+    if Path(file_path).exists():
+        with open(file_path, 'r', newline='', encoding=encoding) as f:
+            content = "".join(f.readlines()[1:])
+
+        with open(file_path, 'w', newline='', encoding=encoding) as f:
+            csv_write = writer(f, delimiter=delimiter, quotechar=quotechar)
+            csv_write.writerow(head)
+
+        with open(file_path, 'a+', newline='', encoding=encoding) as f:
+            f.write(f'{content}')
+
+    else:
+        with open(file_path, 'w', newline='', encoding=encoding) as f:
+            csv_write = writer(f, delimiter=delimiter, quotechar=quotechar)
+            csv_write.writerow(head)
+
+
+def _set_xlsx_head(file_path: str, head: Union[list, tuple]) -> None:
+    """设置xlsx文件的表头            \n
+    :param file_path: 文件路径
+    :param head: 表头列表或元组
+    :return: None
+    """
+    wb = load_workbook(file_path) if Path(file_path).exists() else Workbook()
+    ws = wb.active
+
+    for key, i in enumerate(head, 1):
+        ws.cell(1, key).value = i
+
+    wb.save(file_path)
+    wb.close()
+
+
+def _parse_coord(coord: Union[int, str, list, tuple],
+                 col: int = None,
+                 disable_type: Union[type, list, tuple] = None) -> Tuple[int, int]:
+    """解析坐标，返回坐标tuple                                              \n
+    :param coord: 坐标
+    :param col: 列号，用于只传入行号的情况
+    :param disable_type: 禁用的格式，可以传入单个格式或格式组成的list或tuple
+    :return: 坐标tuple（行, 列）
+    """
+    if disable_type and isinstance(coord, disable_type):
+        raise TypeError(f'当前坐标类型不允许为{disable_type}')
+
+    if isinstance(coord, (int, float)):
+        if col:
+            return int(coord), col
+        else:
+            raise ValueError('只输入行号时必须同时输入列号')
+
+    if isinstance(coord, str):
+        if ',' in coord:  # 'A3'形式
+            coord = coord.replace(' ', '').split(',')
+        else:  # '3,1'形式
+            xy = coordinate_from_string(coord)
+            return xy[1], column_index_from_string(xy[0])
+
+    if isinstance(coord, (tuple, list)) and len(coord) == 2:
+        return int(coord[0]), int(coord[1])
+    else:
+        raise ValueError('list或tuple时长度必须为2')
+
+
+def _process_content(content: Any) -> Union[int, str, float, None]:
+    if isinstance(content, (int, str, float, type(None))):
+        return content
+    elif isinstance(content, Cell):
+        return content.value
+    else:
+        return str(content)
