@@ -3,20 +3,18 @@ from csv import reader as csv_reader, writer as csv_writer
 from pathlib import Path
 from typing import Union, List
 
-from openpyxl import load_workbook
+from openpyxl import load_workbook, Workbook
 from openpyxl.utils import column_index_from_string
-from openpyxl.utils.cell import coordinate_from_string
 
-from .base import BaseRecorder, _data_to_list
+from .base import BaseRecorder, _data_to_list, _parse_coord, _process_content
 
 
 class Filler(BaseRecorder):
     """Filler类用于根据现有文件中的关键字向文件填充数据"""
-    SUPPORTS = ('xlsx', 'csv')
 
     def __init__(self,
                  path: Union[str, Path],
-                 cache_size: int = 50,
+                 cache_size: int = None,
                  key_cols: Union[str, int, list, tuple] = 1,
                  begin_row: int = 2,
                  sign_col: Union[str, int] = 2,
@@ -115,14 +113,23 @@ class Filler(BaseRecorder):
         self.data_col = sign or self.data_col
         self.__init__(path, self.cache_size, key_cols, begin_row, sign_col, sign, data_col)
 
-    def add_data(self, data: Union[list, tuple, dict]) -> None:
+    def add_data(self,
+                 data: Union[list, tuple, dict, int, str, float],
+                 coord: Union[list, tuple, str, int] = None) -> None:
         """添加数据                                                                   \n
         数据格式：第一位为行号或坐标（int或str），第二位开始为数据，数据可以是list, tuple, dict
         :param data: 要添加的内容，第一位为行号，其余为要添加的内容
+        :param coord: 要添加数据的坐标，仅用于添加一行数据
         :return: None
         """
         if not data:
             return
+
+        if coord is not None:
+            coord = _parse_coord(coord, self.data_col)
+            coord = f'{coord[0]},{coord[1]}'
+            data = (coord, data)
+
         if isinstance(data, dict) or isinstance(data[0], (int, str)):  # 只有一个数据的情况
             data = (data,)
 
@@ -152,6 +159,21 @@ class Filler(BaseRecorder):
         if 0 < self.cache_size <= len(self._data):
             self.record()
 
+    def set_link(self,
+                 coord: Union[int, str, tuple, list],
+                 link: str,
+                 content: Union[int, str, float] = None) -> None:
+        """为单元格设置超链接                          \n
+        :param coord: 单元格坐标
+        :param link: 超链接
+        :param content: 单元格内容
+        :return: None
+        """
+        if self.type != 'xlsx':
+            raise TypeError('set_link()只支持xlsx格式。')
+
+        self.add_data(('set_link', coord, link, content))
+
     def _record(self) -> None:
         """记录数据"""
         col = self.data_col if isinstance(self.data_col, int) else column_index_from_string(self.data_col)
@@ -192,14 +214,12 @@ def _get_xlsx_keys(path: str,
     key_cols = [i if isinstance(i, int) else column_index_from_string(i) for i in key_cols]
     sign_col = column_index_from_string(sign_col) if isinstance(sign_col, str) else sign_col
 
-    wb = load_workbook(path, read_only=True)
+    wb = load_workbook(path, data_only=True, read_only=True)
     ws = wb.active
 
-    res_keys = []
-    for row in range(begin_row, ws.max_row + 1):
-        if ws.cell(row, sign_col).value == sign:
-            key = [row]
-            res_keys.append(key + [ws.cell(row, i).value for i in key_cols])
+    res_keys = [[ind] + [i.value for k, i in enumerate(row, 1) if k in key_cols]
+                for ind, row in enumerate(ws.rows, 1)
+                if ind >= begin_row and row[sign_col - 1].value == sign]
 
     wb.close()
     return res_keys
@@ -258,21 +278,20 @@ def _fill_to_xlsx(file_path: str,
     :param col: 开始记录的列号
     :return: None
     """
-    wb = load_workbook(file_path)
+    wb = load_workbook(file_path) if Path(file_path).exists() else Workbook()
     ws = wb.active
 
     for i in data:
-        for key, j in enumerate(_data_to_list(i[1:], before, after)):
-            if isinstance(i[0], int):  # 行号
-                ws.cell(i[0], col + key).value = j
-            elif isinstance(i[0], str):
-                if ',' in i[0]:  # 坐标 如'3,2'
-                    row, col = i[0].split(',')
-                    ws.cell(int(row), int(col)).value = j
-                else:  # 坐标 如'A8'
-                    ws[i[0]].value = j
-            else:
-                raise TypeError(f'数据第一位必须是int（行号）、str（eg."B3"或"3,2"）。现在是：{i[0]}')
+        if i[0] == 'set_link':
+            row, col = _parse_coord(i[1], col)
+            cell = ws.cell(row, col)
+            cell.hyperlink = i[2]
+            if i[3] is not None:
+                cell.value = i[3]
+        else:
+            row, col = _parse_coord(i[0], col, (list, tuple))
+            for key, j in enumerate(_data_to_list(i[1:], before, after)):
+                ws.cell(row, col + key).value = _process_content(j)
 
     wb.save(file_path)
     wb.close()
@@ -297,37 +316,31 @@ def _fill_to_csv(file_path: str,
     :param quotechar: 引用符
     :return: None
     """
+    if not Path(file_path).exists():
+        with open(file_path, 'w', encoding=encoding):
+            pass
+
     with open(file_path, 'r', encoding=encoding) as f:
         reader = csv_reader(f, delimiter=delimiter, quotechar=quotechar)
         lines = list(reader)
         lines_len = len(lines)
 
         for i in data:
-            if isinstance(i[0], int):  # 行号
-                row = i[0]
-            elif isinstance(i[0], str):  # 坐标 如'A8'
-                if ',' in i[0]:  # 坐标 如'3,2'
-                    xy = i[0].split(',')
-                    row = int(xy[0])
-                    col = int(xy[1])
-                else:  # 坐标 如'A8'
-                    xy = coordinate_from_string(i[0])
-                    row = xy[1]
-                    col = column_index_from_string(xy[0])
-            else:
-                raise TypeError(f'数据第一位必须是int（行号）、str（eg."B3"或"3,2"）。现在是：{i[0]}')
+            now_data = _data_to_list(i[1:], before, after)
+            row, col = _parse_coord(i[0], col, (list, tuple))
 
             # 若行数不够，填充行数
             for _ in range(row - lines_len):
                 lines.append([])
                 lines_len += 1
 
+            row_num = row - 1
             # 若列数不够，填充空列
-            lines[row - 1].extend([None] * (col - len(lines[row - 1]) + len(i) - 2))
+            lines[row_num].extend([None] * (col - len(lines[row_num]) + len(now_data) - 1))
 
             # 填充数据
-            for k, j in enumerate(_data_to_list(i[1:], before, after)):
-                lines[row - 1][col + k - 1] = j
+            for k, j in enumerate(now_data):
+                lines[row_num][col + k - 1] = _process_content(j)
 
         writer = csv_writer(open(file_path, 'w', encoding=encoding, newline=''), delimiter=delimiter,
                             quotechar=quotechar)
