@@ -29,20 +29,6 @@ class Recorder(BaseRecorder):
         if 0 < self.cache_size <= len(self._data):
             self.record()
 
-    def set_head(self, head: Union[list, tuple]) -> None:
-        """设置表头。只有 csv 和 xlsx 格式支持设置表头       \n
-        :param head: 表头，列表或元组
-        :return: None
-        """
-        if self.type == 'xlsx':
-            _set_xlsx_head(self.path, head)
-
-        elif self.type == 'csv':
-            _set_csv_head(self.path, head, self.encoding, self.delimiter, self.quote_char)
-
-        else:
-            raise TypeError('只能对xlsx和csv文件设置表头。')
-
     def _record(self) -> None:
         """记录数据"""
         Path(self.path).parent.mkdir(parents=True, exist_ok=True)
@@ -58,6 +44,32 @@ class Recorder(BaseRecorder):
             _record_to_json(self.path, self._data, self._before, self._after, self.encoding)
 
 
+def _get_title(data: Union[list, dict],
+               before: Union[list, dict, None] = None,
+               after: Union[list, dict, None] = None) -> Union[list, None]:
+    """获取表头列表                  \n
+    :param data: 数据列表或字典
+    :param before: 数据前的列
+    :param after: 数据后的列
+    :return: 表头列表
+    """
+    if isinstance(data, (tuple, list)):
+        return None
+
+    return_list = []
+    for i in (before, data, after):
+        if isinstance(i, dict):
+            return_list.extend(list(i))
+        elif i is None:
+            pass
+        elif isinstance(i, list):
+            return_list.extend(['' for _ in range(len(i))])
+        else:
+            return_list.extend([''])
+
+    return return_list
+
+
 def _record_to_xlsx(file_path: str,
                     data: list,
                     before: Union[list, tuple, dict] = None,
@@ -82,7 +94,7 @@ def _record_to_xlsx(file_path: str,
             ws.append(title)
 
     for i in data:
-        ws.append(_data_to_list(i, before, after))
+        ws.append(_data_to_list(i, before, after, True))
 
     wb.save(file_path)
     wb.close()
@@ -113,7 +125,7 @@ def _record_to_csv(file_path: str,
         if title:
             csv_write.writerow(title)
         for i in data:
-            csv_write.writerow(_data_to_list(i, before, after))
+            csv_write.writerow(_data_to_list(i, before, after, True))
 
 
 def _record_to_txt(file_path: str,
@@ -130,7 +142,7 @@ def _record_to_txt(file_path: str,
     :return: None
     """
     with open(file_path, 'a+', encoding=encoding) as f:
-        all_data = [f'{_data_to_list_or_dict(i, before, after)}\n' for i in data]
+        all_data = [f'{_data_to_list_or_dict(i, before, after, True)}\n' for i in data]
         f.write(''.join(all_data))
 
 
@@ -154,84 +166,10 @@ def _record_to_json(file_path: str,
             json_data = load(f)
 
         for i in data:
-            i = _data_to_list_or_dict(i, before, after)
-            json_data.append(i)
+            json_data.append(_data_to_list_or_dict(i, before, after, True))
 
     else:
-        json_data = [_data_to_list_or_dict(i, before, after) for i in data]
+        json_data = [_data_to_list_or_dict(i, before, after, True) for i in data]
 
     with open(file_path, 'w', encoding=encoding) as f:
         dump(json_data, f)
-
-
-def _set_xlsx_head(file_path: str, head: Union[list, tuple]) -> None:
-    """设置xlsx文件的表头            \n
-    :param file_path: 文件路径
-    :param head: 表头列表或元组
-    :return: None
-    """
-    wb = load_workbook(file_path) if Path(file_path).exists() else Workbook()
-    ws = wb.active
-
-    for key, i in enumerate(head, 1):
-        ws.cell(1, key).value = i
-
-    wb.save(file_path)
-    wb.close()
-
-
-def _set_csv_head(file_path: str,
-                  head: Union[list, tuple],
-                  encoding: str = 'utf-8',
-                  delimiter: str = ',',
-                  quotechar: str = '"') -> None:
-    """设置csv文件的表头              \n
-    :param file_path: 文件路径
-    :param head: 表头列表或元组
-    :param encoding: 编码
-    :param delimiter: 分隔符
-    :param quotechar: 引用符
-    :return: None
-    """
-    from csv import writer
-    if Path(file_path).exists():
-        with open(file_path, 'r', newline='', encoding=encoding) as f:
-            content = "".join(f.readlines()[1:])
-
-        with open(file_path, 'w', newline='', encoding=encoding) as f:
-            csv_write = writer(f, delimiter=delimiter, quotechar=quotechar)
-            csv_write.writerow(head)
-
-        with open(file_path, 'a+', newline='', encoding=encoding) as f:
-            f.write(f'{content}')
-
-    else:
-        with open(file_path, 'w', newline='', encoding=encoding) as f:
-            csv_write = writer(f, delimiter=delimiter, quotechar=quotechar)
-            csv_write.writerow(head)
-
-
-def _get_title(data: Union[list, dict],
-               before: Union[list, dict, None] = None,
-               after: Union[list, dict, None] = None) -> Union[list, None]:
-    """获取表头列表                  \n
-    :param data: 数据列表或字典
-    :param before: 数据前的列
-    :param after: 数据后的列
-    :return: 表头列表
-    """
-    if isinstance(data, (tuple, list)):
-        return None
-
-    return_list = []
-    for i in (before, data, after):
-        if isinstance(i, dict):
-            return_list.extend(list(i))
-        elif i is None:
-            pass
-        elif isinstance(i, list):
-            return_list.extend(['' for _ in range(len(i))])
-        else:
-            return_list.extend([''])
-
-    return return_list
